@@ -52,7 +52,6 @@ export class ButtonExtension
     const start = async () => {
       // Get the current file contents
       const file = await getFileContents(panel, context);
-      console.log(file);
       // POST to Atlas the file contents/lab model
       postLabModel(axiosHandler(Globals.TOKEN), file);
     };
@@ -85,19 +84,19 @@ async function activate(
   console.log("Activated skillsnetwork-authoring-extension button plugin!");
 
   // init the token, globals
-  const token = ATLAS_TOKEN();
+  const token = await ATLAS_TOKEN();
 
   // Add the Publish widget to the lab environment
   app.docRegistry.addWidgetExtension('Notebook', new ButtonExtension());
 
-  console.log('Detected your environment as: ', Globals.AUTHOR_ENV);
-  //console.log(Globals.PY_KERNEL_NAME, Globals.LAB_TOOL_TYPE);
-
-  const parsedToken = parseJwt(token)
-  const labFilename = getLabFilePath(parsedToken);
+  console.log('Detected your environment as: ', Globals.LAB_TOOL_TYPE, Globals.AUTHOR_ENV);
+  console.log('Using default kernel: ', Globals.PY_KERNEL_NAME);
 
   // Only try to load up a notebook when author is using the browser tool (not in local)
   if (Globals.AUTHOR_ENV === 'browser'){
+    const parsedToken = parseJwt(token)
+    const labFilename = getLabFilePath(parsedToken);
+
     // Attempt to open the lab
     let widget = await docManager.createNew(labFilename, 'notebook', { name:  Globals.PY_KERNEL_NAME} ) as any;
     await loadLabContents(widget, axiosHandler(token), Globals.AUTHOR_ENV);
