@@ -2,25 +2,17 @@
 import { AxiosError, AxiosInstance } from 'axios';
 import { show_spinner, showSuccessPublishDialog, showFailurePublishDialog, showFailureImportLabDialog } from './dialog';
 import { Dialog } from '@jupyterlab/apputils';
-import {
-  ATLAS_BASE_URL,
-  ATLAS_TOKEN
-} from './config';
+import { ATLAS_BASE_URL } from './config';
 import axios from 'axios';
 import { Globals } from './config';
 import { source } from './config';
 
-export const axiosHandler = (lab_token?: string): AxiosInstance => {
+export const axiosHandler = (lab_token: string): AxiosInstance => {
   if (lab_token) Globals.TOKEN = lab_token;
-
-  let auth_token: string | undefined;
-
-  lab_token !== undefined ? auth_token = lab_token : auth_token = ATLAS_TOKEN();
-
   const atlasClient = axios.create({
-      baseURL: ATLAS_BASE_URL(),
+      baseURL: ATLAS_BASE_URL,
       headers: {
-        Authorization: `Bearer ${auth_token}`,
+        Authorization: `Bearer ${lab_token}`,
         'Content-Type': 'application/json',
         'Access-Control-Allow-Origin': '*'
       }
@@ -40,7 +32,6 @@ export const getLabModel = (axiosHandler: AxiosInstance) => {
     .get('v1/labs')
     .then(result => {
       Dialog.flush(); //remove spinner
-      console.log(result.data);
       return JSON.parse(result.data.body);
     })
     .catch(error => {
